### Analyse data files from RESPIROMETER
### (code by Nico Blüthgen)

### For detailed description see Mangels et al. 2017 - supplementary material S1

rm(list=ls())
#setwd("~/Desktop/Respi")
setwd("~/Documents/Jule/2016 - TranspiRespi/Paper/Appendix/Respi")
########################   CHOOSE NAMES FOR FILES HERE!!!!! ##################
File1 <- "example_R.txt"          ## Name of data file from respirometer
File2 <- "example_R_Tab.csv"          ## Name of file with basic sample data
File3 <- "example_RResults.csv"          ## Give a name for the results file! 
File4 <- "example_RResults.pdf"          ## Give a name for the pdf with figures! 
pdf(File4)          ## Store all figures as pdf (skip if not required)

respi0 <- read.table(file=File1, header=T, sep=";")          ## read RMS text file
respi0 <- respi0[,-c(13:34)]          ## delete columns for S11-S30
#respi0$Date <- as.POSIXct(paste(respi0$Date), format = "%d.%m.%y")          ## Date format
respi0$Hour <- row(respi0)[,1]*15/60          ## Define the hour of the measurement
str(respi0)

data <- read.table(file=File2, header=T, sep=";")          ## read data info file
StartH <- data$StartH          ## --> define start hour for calculation (all samples)
StopH <- data$StopH          ## --> define stop hour for calculation
MaxX <- max(respi0$Hour)          ## max(hour)
StopH[StopH==0] <- MaxX          ## redefine: replace 0 by max(hour)

MaxRow <- dim(respi0)[1]          ## How many rows?
respi1 <- respi0          ## define new table

### Create new data table: Each row gives the difference to previous row 
for (i in 1:(MaxRow-1)) {
respi1[i+1,3:12] <- respi0[i+1,3:12] - respi0[i,3:12]
}

### Translate from peaks to J/h/g 
respi1[,3:12] <- respi1[,3:12] * 4 * 0.58 / 1000 * 20.1          ## Translate to J/h
Mweight <- matrix(data = data$dry_weight, ncol=10, nrow=MaxRow, byrow=T)          ## Make matrix from weights for multiplication
#respi1[,3:12] <- respi1[,3:12]/Mweight          ## Translate to J/h/g

### One Plot with all samples
MaxY <- max(respi1[,3:12])          ## Define maximum for plot: highest respiration measured
plot(respi1$S1~respi1$Hour, xlab="Time [hours]", ylab="Respiration [J/h]", ylim=c(0,MaxY))
for (s in 1:10) {          ## Loop through samples
  points(respi1[,s+2]~respi1$Hour, col=s)
}

### Single Plots per sample
for (s in 1:10) {          ## Loop through samples
  plot( respi1[,s+2] ~ respi1$Hour, main=paste("No",s," ",data$group[s]), xlab="Time [hours]", ylab="Respiration [J/h/g]", col="red")
  abline(v=StartH[s], col="black", lty=3)
  abline(v=StopH[s], col="black", lty=3)
}

### Make table of main results: Output
Stop <- SMean <- SMax  <- array(data=NA, dim=10)

for (s in 1:10) {          ## Loop through samples
  Stop[s] <- StopH[s]          ## Threshold (maximum h) for data analysis
  SMean[s] <- mean(respi1[ (StartH[s]*4) : (StopH[s]*4), s+2])         ## Mean respiration within range
  SMax[s] <- max(respi1[ (StartH[s]*4) : (StopH[s]*4), s+2])          ## Max respiration within range
}

Mean_g <- SMean/data$dry_weight
Max_g <- SMax/data$dry_weight

Output = data.frame(cbind(levels(data$No)[data$No], levels(data$group)[data$group], 
                          levels(data$site)[data$site], levels(data$trap_type)[data$trap_type],
                          data$Temperature, data$dry_weight, SMean, SMax,Mean_g, Max_g))
colnames(Output) = c("No", "group", "Site", "Trap_type", "Temp[C]" , "Dry weight[mg]", "Mean[J/h]", 
                     "Max[J/h]","Mean_g[J/h/mg]", "Max_g[J/h/mg]")
write.csv2(Output, File3)
Output
dev.off()          # skip if figures not stored as pdf

